## $Id: export.py 17392 2023-04-26 13:06:13Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Exporters for applicant-related stuff.
"""
import grok
import sys
from waeup.kofa.applicants.interfaces import IApplicantBaseData
from waeup.kofa.utils.helpers import iface_names
from kofacustom.nigeria.applicants.export import NigeriaApplicantExporter
from kofacustom.nigeria.applicants.interfaces import INigeriaUGApplicant
from waeup.fceokene.applicants.interfaces import (
    ICustomUGApplicant, ITPURegistration, IUTPRegistration)
from waeup.fceokene.applicants.schools_tpu import SCHOOLS_TPU
from waeup.fceokene.applicants.schools_utp import SCHOOLS_UTP

class CustomApplicantExporter(NigeriaApplicantExporter):
    """Exporter for Nigeria Applicants.
    """

    fields = tuple(sorted(set(
        iface_names(ICustomUGApplicant) +
        iface_names(INigeriaUGApplicant) +
        iface_names(IApplicantBaseData) +
        iface_names(ITPURegistration) +
        iface_names(IUTPRegistration)
        ))) + (
        'password', 'state', 'history', 'container_code', 'application_number',
        'display_fullname', 'application_date',)

    def mangle_value(self, value, name, context=None):
        """
        """
        SCHOOLS = SCHOOLS_TPU.copy()
        SCHOOLS.update(SCHOOLS_UTP)
        if name.startswith('school') and value is not None:
            try:
                value = '%s - %s - %s' % (
                    SCHOOLS[value][0], SCHOOLS[value][1], SCHOOLS[value][2])
            except:
                pass
        if name == 'subj_comb' and value is not None:
            value = value.code
        return super(
            CustomApplicantExporter, self).mangle_value(
            value, name, context=context)